{{- if .Values.oauth2.tls.enabled }}
## <addr>:<port> to listen on for HTTPS clients
https_address = "{{ .Values.oauth2.address }}:4180"
### TLS Settings
tls_cert_file = "/opt/config/certs/tls/tls.crt"
tls_key_file = "/opt/config/certs/tls/tls.key"
{{- else }}
## <addr>:<port> to listen on for HTTP clients
http_address = "{{ .Values.oauth2.address }}:4180"
{{- end }}

## skip SSL checking for HTTPS requests
# ssl_insecure_skip_verify = true

{{- if .Values.oauth2.address }}
## the OAuth Redirect URL.
# defaults to the "https://" + requested host header + "/oauth2/callback"
redirect_url = "http{{- if .Values.oauth2.tls.enabled }}s{{- end }}://{{ .Values.oauth2.address }}/oauth2/callback"
{{- end }}

## the http url(s) of the upstream endpoint. If multiple, routing is based on path
# upstreams = [
#     "http://127.0.0.1:8080/"
# ]
upstreams = {{ .Values.oauth2.upstreams | toJson }}


## Email Domains to allow authentication for (this authorizes any email on this domain)
## for more granular authorization use `authenticated_emails_file`
## To authorize any email addresses use "*"
email_domains = ["*"]

## The OAuth Client ID, Secret
client_id = "{{ .Values.oauth2.client.id }}"
client_secret = "{{ randAlphaNum 5 }}"

### Cookie Settings
## Name     - the cookie name
# cookie_name = "_oauth2_proxy"
## Secret   - the seed string for secure cookies; should be 16, 24, or 32 bytes
##            for use with an AES cipher when cookie_refresh or pass_access_token
##            is set
cookie_secret = "{{ randAlphaNum 16 | b64enc }}"
## Domain   - (optional) cookie domain to force cookies to (ie: .yourcompany.com)
# cookie_domains = ""
## Expire   - (duration) expire timeframe for cookie
# cookie_expire = "168h"
## Refresh  - (duration) refresh the cookie when duration has elapsed after cookie was initially set.
##            Should be less than cookie_expire; set to 0 to disable.
##            On refresh, OAuth token is re-validated.
##            (ie: 1h means tokens are refreshed on request 1hr+ after it was set)
# cookie_refresh = ""
## Secure   - secure cookies are only sent by the browser of a HTTPS connection (recommended)
# cookie_secure = true
{{- if not .Values.oauth2.tls.enabled }}
cookie_secure = false
{{- end }}
## HttpOnly - httponly cookies are not readable by javascript (recommended)
# cookie_httponly = true
session_cookie_minimal = {{ .Values.oauth2.sessionCookieMinimal | default false }}

## Provider settings
provider = "oidc"
provider_ca_files = ["/opt/config/certs/provider/ca-cert.pem"]
oidc_issuer_url = "{{ .Values.oauth2.discoveryUrl }}"
login_url = "{{ .Values.oauth2.discoveryUrl }}/protocol/openid-connect/auth"
redeem_url = "{{ .Values.oauth2.discoveryUrl }}/protocol/openid-connect/token"
profile_url = "{{ .Values.oauth2.discoveryUrl }}/protocol/openid-connect/userinfo"
validate_url = "{{ .Values.oauth2.discoveryUrl }}/protocol/openid-connect/userinfo"
oidc_groups_claim = "{{ .Values.oauth2.claim.groups }}"
oidc_email_claim = "{{ .Values.oauth2.claim.email }}"
keycloak_groups = {{ .Values.oauth2.roles | toJson }}
scope = "{{ .Values.oauth2.scope }}"
skip_provider_button = {{ .Values.oauth2.skipProviderButton }}
skip_jwt_bearer_tokens = {{ .Values.oauth2.skipJwtBearerToken }}
